=======
Credits
=======

Project and Development Lead
------------------------------

* Silvia Terragni <s.terragni4@campus.unimib.it>
* Elisabetta Fersini <elisabetta.fersini@unimib.it> University of Milano-Bicocca
* Antonio Candelieri <antonio.candelieri@unimib.it> University of Milano-Bicocca


Contributors
------------

* Pietro Tropeano <p.tropeano1@campus.unimib.it> Framework architecture, Preprocessing, Topic Models, Evaluation metrics and Web Dashboard
* Bruno Galuzzi <bruno.galuzzi@unimib.it> Bayesian Optimization
* Silvia Terragni <s.terragni4@campus.unimib.it> Overall project

Past Contributors
------------------
* Lorenzo Famiglini <l.famiglini@campus.unimib.it> Neural models integration
* Davide Pietrasanta <d.pietrasanta@campus.unimib.it> Bayesian Optimization
